CallResult class

result call status and phone number CallResult

Constructors

CallResult({required CallState state, String number = ''})

Properties

hashCode int
The hash code for this object.
no setterinherited
number String
number
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state CallState
state
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

from(int value) CallState
Creates a CallState from an integer value.
fromFlag(Map data) CallResult