FlutterPhoneCallStatePlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • FlutterPhoneCallStatePlatform
Implementers

Constructors

FlutterPhoneCallStatePlatform()
Constructs a FlutterPhoneCallStatePlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getLastCall({bool isAfterLastCall = false}) Future<CallLogData>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onStateChange({required void callback(CallResult result)}) → void
phoneStateChange() Stream<CallResult>
startMonitorService() → void
start monitor service for andro
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance FlutterPhoneCallStatePlatform
The default instance of FlutterPhoneCallStatePlatform to use.
getter/setter pair