PhoneCallState class

Properties

hashCode → int
The hash code for this object.
no setterinherited
phoneStateChange → Stream<CallResult>
get phone call state change phoneStateChange
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getLastCallLog({bool isAfterLastCall = false}) → Future<CallLogData>
get last call log
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onStateChange({required void callback(CallResult result)}) → void
phoneStateChange
startMonitorService() → void
working only android ios auto start startMonitorService
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → PhoneCallState
no setter