CallLogData class
Constructors
- CallLogData({required String callType, required String number, required String date, required int duration, required bool isAnswer})
-
CallLogData.fromJson(Map<
String, dynamic> json) -
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited