CallState enum
Enum representing various call states for a phone call.
- Inheritance
- Available extensions
Values
- end → const CallState
-
The call has ended.
- outgoing → const CallState
-
The call is being dialed (outgoing call).
- outgoingAccept → const CallState
-
The outgoing call has been accepted by the recipient.
- incoming → const CallState
-
An incoming call is received.
- call → const CallState
-
The incoming call has been accepted.
- hold → const CallState
-
holding.
- interruptAndHold → const CallState
-
interrupt call and holding current call.
- none → const CallState
-
The call state is unknown or undefined.
Properties
- description → String
-
Available on CallState, provided by the CallStateExtension extension
Provides a description of the current call state.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited